﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using Telerik.Windows.Controls.ScheduleView;

namespace ScheduleViewAndListBox
{
	public class ViewModel
	{
		public ObservableCollection<Customer> CustomersSource1 { get; private set; }
		public ObservableCollection<CustomAppointment> AppointmentsSource1 { get; private set; }
		

		public ViewModel()
		{
			var monday = new DateTime(DateTime.Today.Year, DateTime.Today.Month, CalendarHelper.GetFirstDayOfWeek(DateTime.Today, DayOfWeek.Sunday).Day);

			this.CustomersSource1 = new ObservableCollection<Customer> 
			{
				new Customer { ID = 1, Name = "Customer 1" },
				new Customer { ID = 2, Name = "Customer 2" },
				new Customer { ID = 3, Name = "Customer 3" },
				new Customer { ID = 4, Name = "Customer 4" },
				new Customer { ID = 5, Name = "Customer 5" } 
			};

			this.AppointmentsSource1 = new ObservableCollection<CustomAppointment> 
			{ 
				new CustomAppointment { Start = monday, End = monday.AddHours(1), Subject = "Appointment 1", IsDone = true },
				new CustomAppointment { Start = monday, End = monday.AddHours(1), Subject = "Appointment 2", IsDone = true },
				new CustomAppointment { Start = monday, End = monday.AddHours(1), Subject = "Appointment 3", IsDone = false },
				new CustomAppointment { Start = monday, End = monday.AddHours(1), Subject = "Appointment 4", IsDone = true },
				new CustomAppointment { Start = monday, End = monday.AddHours(1), Subject = "Appointment 5", IsDone = false } 
			};			
			
		}
	}

	public class Customer
	{
		public string Name { get; set; }
		public int ID { get; set; }

		public Customer Copy()
		{
			return new Customer
			{
				Name = this.Name,
				ID = this.ID
			};
		}
	}

	public class CustomAppointment : Appointment
	{
		private bool isDone;
		public bool IsDone
		{
			get
			{
				return this.Storage<CustomAppointment>().isDone;
			}
			set
			{
				var storage = this.Storage<CustomAppointment>();
				if (storage.isDone != value)
				{
					storage.isDone = value;
					this.OnPropertyChanged(() => this.IsDone);
				}
			}
		}
		public override IAppointment Copy()
		{
			var newAppointment = new CustomAppointment();
			newAppointment.CopyFrom(this);
			return newAppointment;
		}
		public override void CopyFrom(IAppointment other)
		{
			var task = other as CustomAppointment;
			if (task != null)
			{
				this.IsDone = task.IsDone;
			}
			base.CopyFrom(other);
		}
	}
	
}
